@@ -102,7 +102,10 @@ $(function(){
         events: {
             "change": "changeInput"
         },
-        changeInput: function(val){
+        changeInput: function(e){
+            this.updateInput();
+        },
+        updateInput: function(val){
             if (val) $(this.el).children().val(val);
             this.current_selection = $(this.el).children().val();
 
@@ -209,7 +212,7 @@ $(function(){
             this.condition_operand_input_view.options.show = condition.get('operator_required');
             this.condition_operand_input_view.options.placeholder = condition.get('operand_example');
             this.condition_operand_input_view.render();
-            this.condition_operand_input_view.changeInput();
+            this.condition_operand_input_view.updateInput();
 
             // Update condition selector
             this.condition_selector_view.selected_condition = condition;
@@ -346,7 +349,7 @@ $(function(){
             if (condstr) this.condstr_list_view.setSelectedId(condstr);
             if (key) this.condition_key_input_view.updateValue(key);
             if (operator) this.condition_operator_list_view.setSelectedId(operator);
-            if (operand) this.condition_operand_input_view.changeInput(operand);
+            if (operand) this.condition_operand_input_view.updateInput(operand);
         },
         render: function(){
             var template = _.template($('#condition-selector-template').html(), {});
@@ -463,6 +466,17 @@ $(function(){
                 return this.condition_selector_parent_group.updateJSON();
             }
 
+            // Prevent spaces from being entered in or pasted into condition keys and operands
+            $('#condition-key > input, #condition-operand > input').on('keydown', function(e) {
+                return e.which !== 32;
+            }).bind('paste', function() {
+                var input_pasted_in = $(this);
+                setTimeout(function() {
+                    var pasted_text_wo_whitespace = input_pasted_in.val().replace(/\s+/g, '');
+                    input_pasted_in.val(pasted_text_wo_whitespace);
+                });
+            });
+
             $('#condition-json > textarea').val(prettifyJSON(this.encodeJSON()));
         },
         remove_group_if_empty: function(){
@@ -521,6 +535,13 @@ $(function(){
     $('#condition-json > textarea').change(function(){
         reset_condition_selector_widget();
     });
-    reset_condition_selector_widget();
+
+    // HACK: Prevent this JS from running multiple times
+    // by using a global variable. The better way to avoid
+    // this issue is to use a namespace on a per-widget basis.
+    if (!window.djConditionsInitialized) {
+        reset_condition_selector_widget();
+        window.djConditionsInitialized = true;
+    }
 
 });
